@@ -19,7 +19,9 @@ extern "C" {
  */
 
 /** Interface version */
-#define HD_VERSION	20
+#define HD_VERSION	21
+#define HD_MINOR_VERSION	60
+#define HD_FULL_VERSION		(HD_VERSION * 1000 + HD_MINOR_VERSION)
 
 /**
  * @defgroup DEBUGpub Debug flags
@@ -85,6 +87,7 @@ extern "C" {
 #define TAG_USB		3	/**< USB ids. */
 #define TAG_SPECIAL	4	/**< Internally used ids. */
 #define TAG_PCMCIA	5	/**< PCMCIA ids. */
+#define TAG_SDIO	6	/**< SDIO ids. */
 
 /**
  * Get the real id value.
@@ -142,7 +145,7 @@ typedef enum hw_item {
   hw_isapnp, hw_bridge, hw_hub, hw_scsi, hw_ide, hw_memory, hw_dvb,
   hw_pcmcia, hw_pcmcia_ctrl, hw_ieee1394, hw_ieee1394_ctrl, hw_hotplug,
   hw_hotplug_ctrl, hw_zip, hw_pppoe, hw_wlan, hw_redasd, hw_dsl, hw_block,
-  hw_tape, hw_vbe, hw_bluetooth, hw_fingerprint,
+  hw_tape, hw_vbe, hw_bluetooth, hw_fingerprint, hw_mmc_ctrl,
   /** append new entries here */
   hw_unknown, hw_all				/**< hw_all must be last */
 } hd_hw_item_t;
@@ -164,7 +167,8 @@ typedef enum base_classes {
   bc_monitor = 0x100, bc_internal, bc_modem, bc_isdn, bc_ps2, bc_mouse,
   bc_storage_device, bc_network_interface, bc_keyboard, bc_printer,
   bc_hub, bc_braille, bc_scanner, bc_joystick, bc_chipcard, bc_camera,
-  bc_framebuffer, bc_dvb, bc_tv, bc_partition, bc_dsl, bc_bluetooth, bc_fingerprint
+  bc_framebuffer, bc_dvb, bc_tv, bc_partition, bc_dsl, bc_bluetooth, bc_fingerprint,
+  bc_mmc_ctrl
 } hd_base_classes_t;
 
 /** subclass values of bc_monitor */
@@ -213,7 +217,7 @@ typedef enum sc_input {
 /** subclass values of bc_serial */
 typedef enum sc_serial {
   sc_ser_fire, sc_ser_access, sc_ser_ssa, sc_ser_usb, sc_ser_fiber,
-  sc_ser_smbus, sc_ser_other = 0x80
+  sc_ser_smbus, sc_ser_infiniband, sc_ser_other = 0x80
 } hd_sc_serial_t;
 
 /** internal sub class values (bc_internal) */
@@ -274,7 +278,7 @@ typedef enum sc_dsl {
 
 /** prog_if's of sc_ser_usb */
 typedef enum pif_usb_e {
-  pif_usb_uhci = 0, pif_usb_ohci = 0x10, pif_usb_ehci = 0x20,
+  pif_usb_uhci = 0, pif_usb_ohci = 0x10, pif_usb_ehci = 0x20, pif_usb_xhci = 0x30,
   pif_usb_other = 0x80, pif_usb_device = 0xfe
 } hd_pif_usb_t;
 
@@ -296,7 +300,7 @@ typedef enum bus_types {
   /** outside the range of the PCI values */
   bus_ps2 = 0x80, bus_serial, bus_parallel, bus_floppy, bus_scsi, bus_ide, bus_usb,
   bus_adb, bus_raid, bus_sbus, bus_i2o, bus_vio, bus_ccw, bus_iucv, bus_ps3_system_bus,
-  bus_virtio, bus_ibmebus, bus_gameport
+  bus_virtio, bus_ibmebus, bus_gameport, bus_uisvirtpci, bus_mmc, bus_sdio, bus_nd
 } hd_bus_types_t;
 
 /** @} */
@@ -1047,8 +1051,9 @@ typedef struct s_pci_t {
   char *sysfs_id;				/**< sysfs path */
   char *sysfs_bus_id;				/**< sysfs bus id */
   char *modalias;				/**< module alias */
-  unsigned edid_len[4];				/**< edid record length */
-  unsigned char edid_data[4][0x80];		/**< edid record */
+  char *label;					/**< Consistant Device Name (CDN), pci firmware spec 3.1, chapter 4.6.7 */
+  unsigned edid_len[6];				/**< edid record length */
+  unsigned char edid_data[6][0x80];		/**< edid record */
 } pci_t;
 
 /**
@@ -1180,6 +1185,8 @@ typedef struct devtree_s {
   char *path, *filename;
   unsigned pci:1;
   char *name, *model, *device_type, *compatible;
+  char *ccin, *fru_number, *loc_code, *serial_number, *part_number;
+  char *description;
   int class_code;                       /**< class : sub_class : prog-if */
   int vendor_id, device_id, subvendor_id, subdevice_id;
   int revision_id, interrupt;
@@ -1407,6 +1414,7 @@ typedef struct {
  */
 typedef struct {
   unsigned manu_year;
+  unsigned manu_week;
   unsigned min_vsync, max_vsync;	/**< vsync range */
   unsigned min_hsync, max_hsync;	/**< hsync range */
   unsigned clock;			/**< pixel clock in kHz */
@@ -1437,7 +1445,9 @@ typedef enum cpu_arch {
   arch_s390, arch_s390x,
   arch_arm,
   arch_mips,
-  arch_x86_64
+  arch_x86_64,
+  arch_aarch64,
+  arch_riscv
 } hd_cpu_arch_t;
 
 /**
@@ -1629,7 +1639,7 @@ typedef struct hal_device_s {
 typedef enum resource_types {
   res_any, res_phys_mem, res_mem, res_io, res_irq, res_dma, res_monitor,
   res_size, res_disk_geo, res_cache, res_baud, res_init_strings, res_pppd_option,
-  res_framebuffer, res_hwaddr, res_link, res_wlan, res_fc
+  res_framebuffer, res_hwaddr, res_link, res_wlan, res_fc, res_phwaddr
 } hd_resource_types_t;
 
 
@@ -2494,6 +2504,9 @@ typedef struct s_hd_t {
     unsigned hotpluggable:1;	/**< hotpluggable storage device */
     unsigned dualport:1;	/**< OSA Express device with two ports (S/390) */
     unsigned fcoe:1;		/**< fcoe device */
+    unsigned fcoe_offload:2;	/**< fcoe offload capable device */
+    unsigned iscsi_offload:2;	/**< iscsi offload capable  device */
+    unsigned storage_only:2;	/**< storage only network interface */
   } is;
 
   struct tag_s {		/**< this struct is for internal purposes only */
@@ -2579,6 +2592,7 @@ typedef struct s_hd_t {
   hal_prop_t *persistent_prop;	/**< persistent property list */
 
   char *modalias;		/**< module alias */
+  char *label;			/**< Consistent Device Name (CDN), pci firmware spec 3.1, chapter 4.6.7 */
 
   /*
    * These are used internally for memory management.
